==> haskell-control-monad-free-0.6.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: control-monad-free
version: 0.6.2
id: control-monad-free-0.6.2-D8gRCj9jdnL78y3kztZ3ka
key: control-monad-free-0.6.2-D8gRCj9jdnL78y3kztZ3ka
license: LicenseRef-PublicDomain
maintainer: pepeiborra@gmail.com
author: Luke Palmer, Pepe Iborra
stability: stable
homepage: http://github.com/pepeiborra/control-monad-free
synopsis: Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:
    .
    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/
category: Control, Monads
abi: ec632c0b9170a06bc78092936bf47fbc
exposed: True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip
import-dirs: /usr/lib/ghc-8.4.3/site-local/control-monad-free-0.6.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/control-monad-free-0.6.2
hs-libraries: HScontrol-monad-free-0.6.2-D8gRCj9jdnL78y3kztZ3ka
depends:
    base-4.11.1.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock
haddock-html: /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-control-monad-free-0.6.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-control-monad-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: control-monad-free
version: 0.6.2
id: control-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
key: control-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
license: LicenseRef-PublicDomain
maintainer: pepeiborra@gmail.com
author: Luke Palmer, Pepe Iborra
stability: stable
homepage: http://github.com/pepeiborra/control-monad-free
synopsis: Free monads and monad transformers
description:
    This package provides datatypes to construct Free monads,
    Free monad transformers, and useful instances. In addition it
    provides the constructs to avoid quadratic complexity of left
    associative bind, as explained in:
    .
    * Janis Voigtlander, /Asymptotic Improvement of Computations over Free Monads, MPC'\''08/
category: Control, Monads
abi: 5e8df38b7faeaf7b2f4f249a58297c73
exposed: True
exposed-modules:
    Control.Monad.Free Control.Monad.Free.Improve
    Control.Monad.Free.Zip
import-dirs: /usr/lib/ghc-8.6.1/site-local/control-monad-free-0.6.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/control-monad-free-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/control-monad-free-0.6.2
hs-libraries: HScontrol-monad-free-0.6.2-K5OsWkYY4J3IMyPprITsgT
depends:
    base-4.12.0.0 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-control-monad-free/html/control-monad-free.haddock
haddock-html: /usr/share/doc/haskell-control-monad-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
